==> yin_webview-0.0.1.tar.gz: android/src/main/java/com/yin/yin_webview/YinWebviewPlugin.java <==
package com.yin.yin_webview;

import android.annotation.TargetApi;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.graphics.Point;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.Display;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.CookieManager;
import android.webkit.CookieSyncManager;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceError;
import android.webkit.WebResourceRequest;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;

import java.util.EventListener;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MessageCodec;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.plugin.platform.PlatformView;
import io.flutter.plugin.platform.PlatformViewFactory;

/**
 * YinWebviewPlugin
 */
public class YinWebviewPlugin implements MethodCallHandler {
    private Activity activity;
    private WebView webView;
    private Result result;
    private List<Map<String, String>> mCookieList;
    static MethodChannel channel;

    public static void registerWith(Registrar registrar) {
        if (channel == null) {
            channel = new MethodChannel(registrar.messenger(), "yin_webview");
            channel.setMethodCallHandler(new YinWebviewPlugin(registrar.activity()));
        }
    }


    public YinWebviewPlugin(Activity activity) {
        this.activity = activity;

    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        this.result = result;
        if (call.method.equals("launch")) {
            openUrl(call, result);
        } else if (call.method.equals("close")) {
            close(call, result);
        } else if (call.method.equals("reload")) {
            reload(call, result);
        } else if (call.method.equals("back")) {
            back(call, result);
        } else if (call.method.equals("forward")) {
            forward(call, result);
        } else if (call.method.equals("getAllCookies")) {
            getAllCookies(call, result);
        } else if (call.method.equals("cleanCookies")) {
            clearCookies();
        } else if (call.method.equals("resize")) {
            resize(call, result);
        } else {
            result.notImplemented();
        }
    }

    ///打开url
    public void openUrl(MethodCall call, final Result result) {
        String url = call.argument("url");
        String userAgent = call.argument("userAgent");
        boolean withJavascript = call.argument("withJavascript");
        boolean clearCookies = call.argument("clearCookies");
        boolean withZoom = call.argument("withZoom");
        boolean withLocalStorage = call.argument("withLocalStorage");
        Map<String, String> headers = call.argument("headers");
        List<Map<String, String>> cookieList = call.argument("cookieList");
        boolean scrollBar = call.argument("scrollBar");
        boolean allowFileURLs = call.argument("allowFileURLs");

        FrameLayout.LayoutParams params = buildLayoutParams(call);
        this.webView = new WebView(activity);
        webView.getSettings().setJavaScriptEnabled(withJavascript);
        webView.getSettings().setBuiltInZoomControls(withZoom);
        webView.getSettings().setSupportZoom(withZoom);
        webView.getSettings().setDomStorageEnabled(withLocalStorage);
        webView.getSettings().setDatabaseEnabled(true);
        webView.getSettings().setDatabasePath(activity.getApplicationContext().getCacheDir().getAbsolutePath());

        webView.getSettings().setAllowFileAccessFromFileURLs(allowFileURLs);
        webView.getSettings().setAllowUniversalAccessFromFileURLs(allowFileURLs);
        webView.getSettings().setLoadWithOverviewMode(true);
        webView.getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);
        webView.getSettings().setLoadsImagesAutomatically(true);// 加载网页中的图片
        webView.getSettings().setUseWideViewPort(true); //设置使用视图的宽端口
        webView.getSettings().setAllowFileAccess(true);// 可以读取文件缓存(manifest生效)

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            webView.getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_COMPATIBILITY_MODE);
        }

        if (clearCookies) {
            clearCookies();
        }

        if (userAgent != null) {
            webView.getSettings().setUserAgentString(userAgent);
        }

        if (!scrollBar) {
            webView.setVerticalScrollBarEnabled(false);
        }

        this.mCookieList = cookieList;
        setCookie(url);

        if (headers != null) {
            webView.loadUrl(url, headers);
        } else {
            webView.loadUrl(url);
        }

        if (webView != null && webView.getParent() != null) {
            ViewGroup vg = (ViewGroup) (webView.getParent());
            vg.removeView(webView);
        }

        activity.addContentView(webView, params);
        webView.setWebViewClient(new WebViewClient() {
            @Override
            public boolean shouldOverrideUrlLoading(WebView view, String url) {
                view.loadUrl(url);
                return true;
            }

            @Override
            public void onPageStarted(WebView view, String url, Bitmap favicon) {
                super.onPageStarted(view, url, favicon);
                channel.invokeMethod("url", url);
            }

        });
        webView.setWebChromeClient(new WebChromeClient() {
            @Override
            public void onReceivedTitle(WebView view, String title) {
                super.onReceivedTitle(view, title);
                channel.invokeMethod("title", title);
            }
        });
        webView.loadUrl(url);
    }

    ///关闭url
    public void close(MethodCall call, Result result) {
        if (webView != null) {
            ViewGroup vg = (ViewGroup) (webView.getParent());
            vg.removeView(webView);
        }
        webView = null;
    }


    ///重新加载
    public void reload(MethodCall call, Result result) {
        if (webView != null) {
            webView.reload();
        }
    }

    ///返回
    public void back(MethodCall call, Result result) {
        if (webView != null && webView.canGoBack()) {
            webView.goBack();
        }
    }

    ///向前
    public void forward(MethodCall call, Result result) {
        if (webView != null && webView.canGoForward()) {
            webView.goForward();
        }
    }

    ///设置webivew大小
    private void resize(MethodCall call, final MethodChannel.Result result) {
        if (webView != null) {
            FrameLayout.LayoutParams params = buildLayoutParams(call);
            webView.setLayoutParams(params);
        }
        result.success(null);
    }

    ///新增cookie
    private void setCookie(String url) {
        CookieManager cookieManager = CookieManager.getInstance();
        cookieManager.setAcceptCookie(true);
        cookieManager.removeAllCookie();
        cookieManager.removeSessionCookie();//移除
        Uri uri = Uri.parse(url);
        String domain = uri.getHost();

        for (int i = 0; i < this.mCookieList.size(); i++) {
            Map<String, String> map = this.mCookieList.get(i);
            cookieManager.setCookie(domain, map.get("k") + '=' + map.get("v"));
        }
        cookieManager.flush();
    }

    ///清除cookie
    private void clearCookies() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            CookieManager.getInstance().removeAllCookies(new ValueCallback<Boolean>() {
                @Override
                public void onReceiveValue(Boolean aBoolean) {

                }
            });
        } else {
            CookieManager.getInstance().removeAllCookie();
        }
    }

    ///获取cookie
    private void getAllCookies(MethodCall call, final MethodChannel.Result result) {
        String url = call.argument("url");
        CookieManager cookieManager = CookieManager.getInstance();
        String cookieStr = cookieManager.getCookie(url);
        result.success(cookieStr);
    }

    ///绘制视图
    private FrameLayout.LayoutParams buildLayoutParams(MethodCall call) {
        Map<String, Number> rc = call.argument("rect");
        FrameLayout.LayoutParams params;
        if (rc != null) {
            params = new FrameLayout.LayoutParams(
                    dp2px(activity, rc.get("width").intValue()), dp2px(activity,
                    rc.get("height").intValue()));
            params.setMargins(dp2px(activity, rc.get("left").intValue()), dp2px(activity, rc.get(
                    "top").intValue()),
                    0, 0);
        } else {
            Display display = activity.getWindowManager().getDefaultDisplay();
            Point size = new Point();
            display.getSize(size);
            int width = size.x;
            int height = size.y;
            params = new FrameLayout.LayoutParams(width, height);
        }
        return params;
    }

    private int dp2px(Context context, float dp) {
        final float scale = context.getResources().getDisplayMetrics().density;
        return (int) (dp * scale + 0.5f);
    }


}

==> yin_webview-0.0.7.tar.gz: android/src/main/java/com/yin/yin_webview/YinWebviewPlugin.java <==
package com.yin.yin_webview;

import android.annotation.TargetApi;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.graphics.Point;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.Display;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.CookieManager;
import android.webkit.CookieSyncManager;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceError;
import android.webkit.WebResourceRequest;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;

import java.util.EventListener;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MessageCodec;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import io.flutter.plugin.platform.PlatformView;
import io.flutter.plugin.platform.PlatformViewFactory;

/**
 * YinWebviewPlugin
 */
public class YinWebviewPlugin implements MethodCallHandler {
    private Activity activity;
    private WebView webView;
    private Result result;
    private List<Map<String, String>> mCookieList;
    static MethodChannel channel;

    public static void registerWith(Registrar registrar) {
        if (channel == null) {
            channel = new MethodChannel(registrar.messenger(), "yin_webview");
            channel.setMethodCallHandler(new YinWebviewPlugin(registrar.activity()));
        }
    }


    public YinWebviewPlugin(Activity activity) {
        this.activity = activity;

    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        this.result = result;
        if (call.method.equals("launch")) {
            openUrl(call, result);
        } else if (call.method.equals("close")) {
            close(call, result);
        } else if (call.method.equals("reload")) {
            reload(call, result);
        } else if (call.method.equals("back")) {
            back(call, result);
        } else if (call.method.equals("forward")) {
            forward(call, result);
        } else if (call.method.equals("getAllCookies")) {
            getAllCookies(call, result);
        } else if (call.method.equals("cleanCookies")) {
            clearCookies();
        } else if (call.method.equals("resize")) {
            resize(call, result);
        } else {
            result.notImplemented();
        }
    }

    ///打开url
    public void openUrl(MethodCall call, final Result result) {
        String url = call.argument("url");
        String userAgent = call.argument("userAgent");
        boolean clearCookies = call.argument("clearCookies");
        Map<String, String> headers = call.argument("headers");
        List<Map<String, String>> cookieList = call.argument("cookieList");
        boolean scrollBar = call.argument("scrollBar");

        FrameLayout.LayoutParams params = buildLayoutParams(call);
        this.webView = new WebView(activity);
        webView.getSettings().setJavaScriptEnabled(true);
        webView.getSettings().setBuiltInZoomControls(true);
        webView.getSettings().setSupportZoom(true);
        webView.getSettings().setDomStorageEnabled(true);
        webView.getSettings().setDatabaseEnabled(true);
        webView.getSettings().setDatabasePath(activity.getApplicationContext().getCacheDir().getAbsolutePath());

        webView.getSettings().setAllowFileAccessFromFileURLs(true);
        webView.getSettings().setAllowUniversalAccessFromFileURLs(true);
        webView.getSettings().setLoadWithOverviewMode(true);
        webView.getSettings().setCacheMode(WebSettings.LOAD_NO_CACHE);
        webView.getSettings().setLoadsImagesAutomatically(true);// 加载网页中的图片
        webView.getSettings().setUseWideViewPort(true); //设置使用视图的宽端口
        webView.getSettings().setAllowFileAccess(true);// 可以读取文件缓存(manifest生效)

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            webView.getSettings().setMixedContentMode(WebSettings.MIXED_CONTENT_COMPATIBILITY_MODE);
        }

        if (clearCookies) {
            clearCookies();
        }

        if (userAgent != null) {
            webView.getSettings().setUserAgentString(userAgent);
        }

        if (!scrollBar) {
            webView.setVerticalScrollBarEnabled(false);
        }

        this.mCookieList = cookieList;
        setCookie(url);

        if (headers != null) {
            webView.loadUrl(url, headers);
        } else {
            webView.loadUrl(url);
        }

        if (webView != null && webView.getParent() != null) {
            ViewGroup vg = (ViewGroup) (webView.getParent());
            vg.removeView(webView);
        }

        activity.addContentView(webView, params);
        webView.setWebViewClient(new WebViewClient() {
            @Override
            public boolean shouldOverrideUrlLoading(WebView view, String url) {
                view.loadUrl(url);
                return true;
            }

            @Override
            public void onPageStarted(WebView view, String url, Bitmap favicon) {
                super.onPageStarted(view, url, favicon);
                channel.invokeMethod("url", url);
            }

        });
        webView.setWebChromeClient(new WebChromeClient() {
            @Override
            public void onReceivedTitle(WebView view, String title) {
                super.onReceivedTitle(view, title);
                channel.invokeMethod("title", title);
            }
        });
        webView.loadUrl(url);
    }

    ///关闭url
    public void close(MethodCall call, Result result) {
        if (webView != null) {
            ViewGroup vg = (ViewGroup) (webView.getParent());
            vg.removeView(webView);
        }
        webView = null;
        if (mCookieList != null) {
            mCookieList.clear();
            mCookieList = null;
        }
    }


    ///重新加载
    public void reload(MethodCall call, Result result) {
        if (webView != null) {
            webView.reload();
        }
    }

    ///返回
    public void back(MethodCall call, Result result) {
        if (webView != null && webView.canGoBack()) {
            webView.goBack();
        }
    }

    ///向前
    public void forward(MethodCall call, Result result) {
        if (webView != null && webView.canGoForward()) {
            webView.goForward();
        }
    }

    ///设置webivew大小
    private void resize(MethodCall call, final MethodChannel.Result result) {
        if (webView != null) {
            FrameLayout.LayoutParams params = buildLayoutParams(call);
            webView.setLayoutParams(params);
        }
        result.success(null);
    }

    ///新增cookie
    private void setCookie(String url) {
        CookieManager cookieManager = CookieManager.getInstance();
        cookieManager.setAcceptCookie(true);
        cookieManager.removeAllCookie();
        cookieManager.removeSessionCookie();//移除
        Uri uri = Uri.parse(url);
        String domain = uri.getHost();

        for (int i = 0; i < this.mCookieList.size(); i++) {
            Map<String, String> map = this.mCookieList.get(i);
            cookieManager.setCookie(domain, map.get("k") + '=' + map.get("v"));
        }
        cookieManager.flush();
    }

    ///清除cookie
    private void clearCookies() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
            CookieManager.getInstance().removeAllCookies(new ValueCallback<Boolean>() {
                @Override
                public void onReceiveValue(Boolean aBoolean) {

                }
            });
        } else {
            CookieManager.getInstance().removeAllCookie();
        }
    }

    ///获取cookie
    private void getAllCookies(MethodCall call, final MethodChannel.Result result) {
        String url = call.argument("url");
        CookieManager cookieManager = CookieManager.getInstance();
        String cookieStr = cookieManager.getCookie(url);
        result.success(cookieStr);
    }

    ///绘制视图
    private FrameLayout.LayoutParams buildLayoutParams(MethodCall call) {
        Map<String, Number> rc = call.argument("rect");
        FrameLayout.LayoutParams params;
        if (rc != null) {
            params = new FrameLayout.LayoutParams(
                    dp2px(activity, rc.get("width").intValue()), dp2px(activity,
                    rc.get("height").intValue()));
            params.setMargins(dp2px(activity, rc.get("left").intValue()), dp2px(activity, rc.get(
                    "top").intValue()),
                    0, 0);
        } else {
            Display display = activity.getWindowManager().getDefaultDisplay();
            Point size = new Point();
            display.getSize(size);
            int width = size.x;
            int height = size.y;
            params = new FrameLayout.LayoutParams(width, height);
        }
        return params;
    }

    private int dp2px(Context context, float dp) {
        final float scale = context.getResources().getDisplayMetrics().density;
        return (int) (dp * scale + 0.5f);
    }


}
